@@ -13,37 +13,58 @@ if typing.TYPE_CHECKING:
 class Sticker(DiscordObjectBase):
     TYPING = typing.Union[int, str, Snowflake, "Sticker"]
     RESPONSE = typing.Union["Sticker", typing.Awaitable["Sticker"]]
-    RESPONSE_AS_LIST = typing.Union[typing.List["Sticker"], typing.Awaitable[typing.List["Sticker"]]]
+    RESPONSE_AS_LIST = typing.Union[
+        typing.List["Sticker"], typing.Awaitable[typing.List["Sticker"]]
+    ]
     _cache_type = "sticker"
 
     def __init__(self, client: "APIClient", resp: dict):
         super().__init__(client, resp)
-        self.pack_id: typing.Optional[Snowflake] = Snowflake.optional(resp.get("pack_id"))
+        self.pack_id: typing.Optional[Snowflake] = Snowflake.optional(
+            resp.get("pack_id")
+        )
         self.name: str = resp["name"]
         self.description: typing.Optional[str] = resp["description"]
         self.tags: str = resp["tags"]
         self.type: StickerTypes = StickerTypes(resp["type"])
         self.format_type: StickerFormatTypes = StickerFormatTypes(resp["format_type"])
         self.available: typing.Optional[bool] = resp.get("available")
-        self.guild_id: typing.Optional[Snowflake] = Snowflake.optional(resp.get("guild_id"))
+        self.guild_id: typing.Optional[Snowflake] = Snowflake.optional(
+            resp.get("guild_id")
+        )
         self.__user = resp.get("user")
-        self.user: typing.Optional[User] = User.create(client, self.__user) if self.__user else self.__user
+        self.user: typing.Optional[User] = (
+            User.create(client, self.__user) if self.__user else self.__user
+        )
         self.sort_value: typing.Optional[int] = resp.get("sort_value")
 
     def __str__(self) -> str:
         return self.name
 
-    def image_url(self, *, extension: str = "webp", size: int = 1024) -> typing.Optional[str]:
-        return cdn_url("stickers", image_hash=str(self.id), extension=extension, size=size)
+    def image_url(
+        self, *, extension: str = "webp", size: int = 1024
+    ) -> typing.Optional[str]:
+        return cdn_url(
+            "stickers", image_hash=str(self.id), extension=extension, size=size
+        )
 
-    def modify(self,
-               *,
-               name: typing.Optional[str] = None,
-               description: typing.Optional[str] = EmptyObject,
-               tags: typing.Optional[str] = None,
-               reason: typing.Optional[str] = None):
+    def modify(
+        self,
+        *,
+        name: typing.Optional[str] = None,
+        description: typing.Optional[str] = EmptyObject,
+        tags: typing.Optional[str] = None,
+        reason: typing.Optional[str] = None,
+    ):
         if self.guild_id:
-            return self.client.modify_guild_sticker(self.guild_id, self, name=name, description=description, tags=tags, reason=reason)
+            return self.client.modify_guild_sticker(
+                self.guild_id,
+                self,
+                name=name,
+                description=description,
+                tags=tags,
+                reason=reason,
+            )
         else:
             raise TypeError("unable to edit this sticker.")
 
@@ -101,23 +122,36 @@ class StickerItem:
 class StickerPack(DiscordObjectBase):
     TYPING = typing.Union[int, str, Snowflake, "StickerPack"]
     RESPONSE = typing.Union["StickerPack", typing.Awaitable["StickerPack"]]
-    RESPONSE_AS_LIST = typing.Union[typing.List["StickerPack"], typing.Awaitable[typing.List["StickerPack"]]]
+    RESPONSE_AS_LIST = typing.Union[
+        typing.List["StickerPack"], typing.Awaitable[typing.List["StickerPack"]]
+    ]
     _cache_type = "sticker_pack"
 
     def __init__(self, client: "APIClient", resp: dict):
         super().__init__(client, resp)
-        self.stickers: typing.List[Sticker] = [Sticker.create(client, x) for x in resp["stickers"]]
+        self.stickers: typing.List[Sticker] = [
+            Sticker.create(client, x) for x in resp["stickers"]
+        ]
         self.name: str = resp["name"]
         self.sku_id: Snowflake = Snowflake(resp["sku_id"])
-        self.cover_sticker_id: typing.Optional[Snowflake] = Snowflake.optional(resp.get("cover_sticker_id"))
+        self.cover_sticker_id: typing.Optional[Snowflake] = Snowflake.optional(
+            resp.get("cover_sticker_id")
+        )
         self.description: str = resp["description"]
         self.banner_asset_id: Snowflake = Snowflake(resp["banner_asset_id"])
 
     def __str__(self) -> str:
         return self.name
 
-    def banner_url(self, *, extension: str = "webp", size: int = 1024) -> typing.Optional[str]:
-        return cdn_url("app-assets/710982414301790216/store", image_hash=str(self.banner_asset_id), extension=extension, size=size)
+    def banner_url(
+        self, *, extension: str = "webp", size: int = 1024
+    ) -> typing.Optional[str]:
+        return cdn_url(
+            "app-assets/710982414301790216/store",
+            image_hash=str(self.banner_asset_id),
+            extension=extension,
+            size=size,
+        )
 
     def __repr__(self) -> str:
-        return f"<{self.__class__.__name__} id={self.id} name={self.name}>"
\ No newline at end of file
+        return f"<{self.__class__.__name__} id={self.id} name={self.name}>"
